@@ -1,8 +1,7 @@
-from .asset_impact import get_impact_distrib
 from .assets import Asset, PowerGeneratingAsset
 from .calculation import calculate_impacts
 from .curve import ExceedanceCurve
 from .events import Drought, Event, RiverineInundation
 from .hazard_event_distrib import HazardEventDistrib
-from .model import Model
 from .vulnerability_distrib import VulnerabilityDistrib
+from .vulnerability_model import VulnerabilityModelBase
